package com.gic.finance.service;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.finance.dto.OperationUserInfoDTO;
import com.gic.finance.dto.TransferAccountsApprovalDTO;
import com.gic.finance.qo.TransferListQueryQO;

import java.util.List;

/**
 * 转账审批
 * @ClassName: TransferAccountsApprovalApiService 
 * @Description:  
 * @author guojuxing 
 * @date 2019/8/9 11:13 AM 
 */
public interface TransferAccountsApprovalApiService {

    /**
     * 充值类型 发起审批 <br>
     * 商户名称、公司名称、公司logo 发起方姓名 <br>
     * 这数据如果有，需要传，如果没有，我默认给值 <br>
     * @Title: rechargeInitiateApproval 
     * @Description:
      * @author guojuxing
     * @param transferAccountsApprovalDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> rechargeInitiateApproval(TransferAccountsApprovalDTO transferAccountsApprovalDTO);

    /**
     * 短信套餐包类型 发起审批 <br>
     * 商户名称、公司名称、公司logo 发起方姓名 <br>
     * 这数据如果有，需要传，如果没有，我默认给值 <br>
     * @Title: smsInitiateApproval 
     * @Description:
      * @author guojuxing
     * @param transferAccountsApprovalDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> smsInitiateApproval(TransferAccountsApprovalDTO transferAccountsApprovalDTO);

    /**
     * 服务类型 发起审批 <br>
     * 商户名称、公司名称、公司logo 发起方姓名 <br>
     * 这数据如果有，需要传，如果没有，我默认给值 <br>
     * @Title: serviceInitiateApproval 
     * @Description:
      * @author guojuxing
     * @param transferAccountsApprovalDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> serviceInitiateApproval(TransferAccountsApprovalDTO transferAccountsApprovalDTO);

    /**
     * 拓展包类型 发起审批 <br>
     * 商户名称、公司名称、公司logo 发起方姓名 <br>
     * 这数据如果有，需要传，如果没有，我默认给值 <br>
     * @Title: extensionPackageInitiateApproval 
     * @Description:
      * @author guojuxing
     * @param transferAccountsApprovalDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> extensionPackageInitiateApproval(TransferAccountsApprovalDTO transferAccountsApprovalDTO);

    /**
     * 套餐包类型 发起审批 <br>
     * 商户名称、公司名称、公司logo 发起方姓名 <br>
     * 这数据如果有，需要传，如果没有，我默认给值 <br>
     * @Title: packageInitiateApproval 
     * @Description:
      * @author guojuxing
     * @param transferAccountsApprovalDTO 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> packageInitiateApproval(TransferAccountsApprovalDTO transferAccountsApprovalDTO);

    /**
     * 主键查询
     * @Title: getById 
     * @Description: 
      * @author guojuxing 
     * @param transferApprovalId 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.finance.dto.TransferAccountsApprovalDTO> 
      */
    ServiceResponse<TransferAccountsApprovalDTO> getById(Integer transferApprovalId);

    /**
     * 根据订单流水号查询单条数据
     * @Title: getByOrderNumber 
     * @Description:
      * @author guojuxing
     * @param orderNumber 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.finance.dto.TransferAccountsApprovalDTO> 
      */
    ServiceResponse<TransferAccountsApprovalDTO> getByOrderNumber(String orderNumber);

    /**
     * 审批通过操作
     * @Title: agreeApproval 
     * @Description: 
      * @author guojuxing 
     * @param transferApprovalId
     * @param accountAmount 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> agreeApproval(Integer transferApprovalId, Double accountAmount, OperationUserInfoDTO userInfoDTO);

    /**
     * 回驳
     * @Title: rejectApproval 
     * @Description: 
      * @author guojuxing 
     * @param transferApprovalId  转账审批主键
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> rejectApproval(Integer transferApprovalId, OperationUserInfoDTO userInfoDTO);

    /**
     * 取消
     * @Title: rejectApproval 
     * @Description:
      * @author guojuxing
     * @param orderSerialNumber 订单流水号 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> cancelApproval(String orderSerialNumber);

    /**
     * 取消审批
     * @Title: cancelApproval 
     * @Description:
      * @author guojuxing
     * @param transferApprovalId 
     * @return  com.gic.api.base.commons.ServiceResponse<java.lang.Void> 
      */
    ServiceResponse<Void> cancelApproval(Integer transferApprovalId);

    /**
     * 分页查询
     * @Title: listTransferAccountsApproval 
     * @Description:
      * @author guojuxing
     * @param params 
     * @return  com.gic.api.base.commons.ServiceResponse<com.gic.api.base.commons.Page<com.gic.finance.dto.TransferAccountsApprovalDTO>> 
      */
    ServiceResponse<Page<TransferAccountsApprovalDTO>> listTransferAccountsApproval(TransferListQueryQO params);

    /**
     * 订单流水号查询审批数据
     * @Title: listByOrderSerialNumber 
     * @Description:
      * @author guojuxing
     * @param orderSerialNumberList 
     * @return  com.gic.api.base.commons.ServiceResponse<java.util.List<com.gic.finance.dto.TransferAccountsApprovalDTO>> 
      */
    ServiceResponse<List<TransferAccountsApprovalDTO>> listByOrderSerialNumber(List<String> orderSerialNumberList);
}
